@@ -4,7 +4,6 @@ import functools
 import heapq
 import itertools
 import math
-import operator as op
 import threading
 import warnings
 from collections.abc import Callable, Iterable, Iterator, Sequence
@@ -44,7 +43,7 @@ from cognite.client.data_classes.assets import (
     SortableAssetProperty,
 )
 from cognite.client.data_classes.filters import _BASIC_FILTERS, Filter, _validate_filter
-from cognite.client.exceptions import CogniteAPIError
+from cognite.client.exceptions import CogniteAPIError, CogniteMultiException
 from cognite.client.utils._auxiliary import split_into_chunks, split_into_n_parts
 from cognite.client.utils._concurrency import ConcurrencySettings, classify_error, execute_tasks
 from cognite.client.utils._identifier import IdentifierSequence
@@ -243,16 +242,14 @@ class AssetsAPI(APIClient):
 
         Examples:
 
-            Get asset by id::
+            Get asset by id:
 
                 >>> from cognite.client import CogniteClient
                 >>> client = CogniteClient()
                 >>> res = client.assets.retrieve(id=1)
 
-            Get asset by external id::
+            Get asset by external id:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> res = client.assets.retrieve(external_id="1")
         """
         identifier = IdentifierSequence.load(ids=id, external_ids=external_id).as_singleton()
@@ -276,16 +273,14 @@ class AssetsAPI(APIClient):
 
         Examples:
 
-            Get assets by id::
+            Get assets by id:
 
                 >>> from cognite.client import CogniteClient
                 >>> client = CogniteClient()
                 >>> res = client.assets.retrieve_multiple(ids=[1, 2, 3])
 
-            Get assets by external id::
+            Get assets by external id:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> res = client.assets.retrieve_multiple(external_ids=["abc", "def"], ignore_unknown_ids=True)
         """
         identifiers = IdentifierSequence.load(ids=ids, external_ids=external_ids)
@@ -341,10 +336,8 @@ class AssetsAPI(APIClient):
 
         Count the number of assets with the metadata key "timezone" in your CDF project:
 
-            >>> from cognite.client import CogniteClient
             >>> from cognite.client.data_classes.filters import ContainsAny
             >>> from cognite.client.data_classes.assets import AssetProperty
-            >>> client = CogniteClient()
             >>> has_timezone = ContainsAny(AssetProperty.metadata, "timezone")
             >>> asset_count = client.assets.aggregate_count(advanced_filter=has_timezone)
 
@@ -385,10 +378,8 @@ class AssetsAPI(APIClient):
 
             Count the number of timezones (metadata key) for assets with the word "critical" in the description in your CDF project:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes.filters import Search
                 >>> from cognite.client.data_classes.assets import AssetProperty
-                >>> client = CogniteClient()
                 >>> is_critical = Search(AssetProperty.description, "critical")
                 >>> critical_assets = client.assets.aggregate_cardinality_values(
                 ...     AssetProperty.metadata_key("timezone"),
@@ -472,12 +463,10 @@ class AssetsAPI(APIClient):
 
         Get the different labels with count used for assets created after 2020-01-01 in your CDF project:
 
-            >>> from cognite.client import CogniteClient
             >>> from cognite.client.data_classes import filters
             >>> from cognite.client.data_classes.assets import AssetProperty
             >>> from cognite.client.utils import timestamp_to_ms
             >>> from datetime import datetime
-            >>> client = CogniteClient()
             >>> created_after_2020 = filters.Range(AssetProperty.created_time, gte=timestamp_to_ms(datetime(2020, 1, 1)))
             >>> result = client.assets.aggregate_unique_values(AssetProperty.labels, advanced_filter=created_after_2020)
             >>> print(result.unique)
@@ -485,11 +474,9 @@ class AssetsAPI(APIClient):
         Get the different labels with count for assets updated after 2020-01-01 in your CDF project, but exclude all labels that
         starts with "test":
 
-            >>> from cognite.client import CogniteClient
             >>> from cognite.client.data_classes.assets import AssetProperty
             >>> from cognite.client.data_classes import aggregations
             >>> from cognite.client.data_classes import filters
-            >>> client = CogniteClient()
             >>> not_test = aggregations.Not(aggregations.Prefix("test"))
             >>> created_after_2020 = filters.Range(AssetProperty.last_updated_time, gte=timestamp_to_ms(datetime(2020, 1, 1)))
             >>> result = client.assets.aggregate_unique_values(AssetProperty.labels, advanced_filter=created_after_2020, aggregate_filter=not_test)
@@ -565,7 +552,7 @@ class AssetsAPI(APIClient):
 
         Examples:
 
-            Create new assets::
+            Create new assets:
 
                 >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetWrite
@@ -573,11 +560,9 @@ class AssetsAPI(APIClient):
                 >>> assets = [AssetWrite(name="asset1"), AssetWrite(name="asset2")]
                 >>> res = client.assets.create(assets)
 
-            Create asset with label::
+            Create asset with label:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetWrite, Label
-                >>> client = CogniteClient()
                 >>> asset = AssetWrite(name="my_pump", labels=[Label(external_id="PUMP")])
                 >>> res = client.assets.create(asset)
         """
@@ -734,7 +719,7 @@ class AssetsAPI(APIClient):
 
         Examples:
 
-            Delete assets by id or external id::
+            Delete assets by id or external id:
 
                 >>> from cognite.client import CogniteClient
                 >>> client = CogniteClient()
@@ -775,7 +760,7 @@ class AssetsAPI(APIClient):
             Asset | AssetList: Updated asset(s)
 
         Examples:
-            Perform a partial update on an asset, updating the description and adding a new field to metadata::
+            Perform a partial update on an asset, updating the description and adding a new field to metadata:
 
                 >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
@@ -786,11 +771,9 @@ class AssetsAPI(APIClient):
                 >>> another_update = AssetUpdate(id=1).description.set(None)
                 >>> res2 = client.assets.update(another_update)
 
-            Remove the metadata on an asset::
+            Remove the metadata on an asset:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
-                >>> client = CogniteClient()
                 >>> my_update = AssetUpdate(id=1).metadata.add({"key": "value"})
                 >>> res1 = client.assets.update(my_update)
                 >>> another_update = AssetUpdate(id=1).metadata.set(None)
@@ -798,27 +781,21 @@ class AssetsAPI(APIClient):
                 >>> another_update2 = AssetUpdate(id=1).metadata.set({})
                 >>> res2 = client.assets.update(another_update)
 
-            Attach labels to an asset::
+            Attach labels to an asset:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
-                >>> client = CogniteClient()
                 >>> my_update = AssetUpdate(id=1).labels.add(["PUMP", "VERIFIED"])
                 >>> res = client.assets.update(my_update)
 
-            Detach a single label from an asset::
+            Detach a single label from an asset:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
-                >>> client = CogniteClient()
                 >>> my_update = AssetUpdate(id=1).labels.remove("PUMP")
                 >>> res = client.assets.update(my_update)
 
-            Replace all labels for an asset::
+            Replace all labels for an asset:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
-                >>> client = CogniteClient()
                 >>> my_update = AssetUpdate(id=1).labels.set("PUMP")
                 >>> res = client.assets.update(my_update)
         """
@@ -908,10 +885,8 @@ class AssetsAPI(APIClient):
             To make it easier to avoid spelling mistakes and easier to look up available properties
             for filtering and sorting, you can also use the `AssetProperty` and `SortableAssetProperty` Enums.
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import filters
                 >>> from cognite.client.data_classes.assets import AssetProperty, SortableAssetProperty
-                >>> client = CogniteClient()
                 >>> in_timezone = filters.Prefix(AssetProperty.metadata_key("timezone"), "Europe")
                 >>> res = client.assets.filter(
                 ...     filter=in_timezone,
@@ -960,34 +935,26 @@ class AssetsAPI(APIClient):
 
         Examples:
 
-            Search for assets by fuzzy search on name::
+            Search for assets by fuzzy search on name:
 
                 >>> from cognite.client import CogniteClient
                 >>> client = CogniteClient()
                 >>> res = client.assets.search(name="some name")
 
-            Search for assets by exact search on name::
+            Search for assets by exact search on name:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> res = client.assets.search(filter={"name": "some name"})
 
-            Search for assets by improved multi-field fuzzy search::
+            Search for assets by improved multi-field fuzzy search:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> res = client.assets.search(query="TAG 30 XV")
 
-            Search for assets using multiple filters, finding all assets with name similar to `xyz` with parent asset `123` or `456` with source `some source`::
+            Search for assets using multiple filters, finding all assets with name similar to `xyz` with parent asset `123` or `456` with source `some source`:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> res = client.assets.search(name="xyz",filter={"parent_ids": [123,456],"source": "some source"})
 
             Search for an asset with an attached label:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> my_label_filter = LabelFilter(contains_all=["PUMP"])
                 >>> res = client.assets.search(name="xyz",filter=AssetFilter(labels=my_label_filter))
         """
@@ -1099,40 +1066,32 @@ class AssetsAPI(APIClient):
 
         Examples:
 
-            List assets::
+            List assets:
 
                 >>> from cognite.client import CogniteClient
                 >>> client = CogniteClient()
                 >>> asset_list = client.assets.list(limit=5)
 
-            Iterate over assets::
+            Iterate over assets:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> for asset in client.assets:
                 ...     asset # do something with the asset
 
-            Iterate over chunks of assets to reduce memory load::
+            Iterate over chunks of assets to reduce memory load:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> for asset_list in client.assets(chunk_size=2500):
                 ...     asset_list # do something with the assets
 
-            Filter assets based on labels::
+            Filter assets based on labels:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import LabelFilter
-                >>> client = CogniteClient()
                 >>> my_label_filter = LabelFilter(contains_all=["PUMP", "VERIFIED"])
                 >>> asset_list = client.assets.list(labels=my_label_filter)
 
             Using advanced filter, find all assets that have a metadata key 'timezone' starting with 'Europe',
             and sort by external id ascending:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import filters
-                >>> client = CogniteClient()
                 >>> in_timezone = filters.Prefix(["metadata", "timezone"], "Europe")
                 >>> res = client.assets.list(advanced_filter=in_timezone, sort=("external_id", "asc"))
 
@@ -1142,10 +1101,8 @@ class AssetsAPI(APIClient):
             To make it easier to avoid spelling mistakes and easier to look up available properties
             for filtering and sorting, you can also use the `AssetProperty` and `SortableAssetProperty` Enums.
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import filters
                 >>> from cognite.client.data_classes.assets import AssetProperty, SortableAssetProperty
-                >>> client = CogniteClient()
                 >>> in_timezone = filters.Prefix(AssetProperty.metadata_key("timezone"), "Europe")
                 >>> res = client.assets.list(
                 ...     advanced_filter=in_timezone,
@@ -1153,9 +1110,7 @@ class AssetsAPI(APIClient):
 
             Combine filter and advanced filter:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import filters
-                >>> client = CogniteClient()
                 >>> not_instrument_lvl5 = filters.And(
                 ...    filters.ContainsAny("labels", ["Level5"]),
                 ...    filters.Not(filters.ContainsAny("labels", ["Instrument"]))
@@ -1465,27 +1420,24 @@ class _AssetHierarchyCreator:
 
     def _raise_latest_exception(self, exceptions: list[Exception], successful: list[Asset]) -> NoReturn:
         *_, latest_exception = exceptions
-        common = dict(
-            successful=AssetList(successful),
-            unknown=AssetList(self.unknown),
-            failed=AssetList(self.failed),
-            unwrap_fn=op.attrgetter("external_id"),
-            cluster=self.assets_api._config.cdf_cluster,
-        )
         err_message = "One or more errors happened during asset creation. Latest error:"
         if isinstance(latest_exception, CogniteAPIError):
             raise CogniteAPIError(
                 message=f"{err_message} {latest_exception.message}",
                 x_request_id=latest_exception.x_request_id,
                 code=latest_exception.code,
+                cluster=self.assets_api._config.cdf_cluster,
+                project=self.assets_api._config.project,
                 extra=latest_exception.extra,
-                **common,  # type: ignore [arg-type]
+                successful=AssetList(successful),
+                unknown=AssetList(self.unknown),
+                failed=AssetList(self.failed),
             )
         # If a non-Cognite-exception was raised, we still raise CogniteAPIError, but use 'from' to not hide
-        # the underlying reason from the user. We also do this because we promise that 'successful', 'unknown'
+        # the underlying reason from the user. We do this because we promise that 'successful', 'unknown'
         # and 'failed' can be inspected:
-        raise CogniteAPIError(
-            message=f"{err_message} {type(latest_exception).__name__}('{latest_exception}')",
-            code=None,  # type: ignore [arg-type]
-            **common,  # type: ignore [arg-type]
+        raise CogniteMultiException(
+            successful=AssetList(successful),
+            unknown=AssetList(self.unknown),
+            failed=AssetList(self.failed),
         ) from latest_exception
