@@ -629,7 +629,13 @@ class FilesAPI(APIClient):
             res = self._post(url_path=f"{self._RESOURCE_PATH}/uploadlink", json={"items": identifiers.as_dicts()})
         except CogniteAPIError as e:
             if e.code == 403:
-                raise CogniteAuthorizationError(message=e.message, code=e.code, x_request_id=e.x_request_id) from e
+                raise CogniteAuthorizationError(
+                    message=e.message,
+                    code=e.code,
+                    x_request_id=e.x_request_id,
+                    cluster=self._config.cdf_cluster,
+                    project=self._config.project,
+                ) from e
             raise
 
         return self._upload_bytes(content, res.json()["items"][0])
@@ -730,7 +736,13 @@ class FilesAPI(APIClient):
             if e.code == 403 and "insufficient access rights" in e.message:
                 dsid_notice = " Try to provide a data_set_id." if data_set_id is None else ""
                 msg = f"Could not create a file due to insufficient access rights.{dsid_notice}"
-                raise CogniteAuthorizationError(message=msg, code=e.code, x_request_id=e.x_request_id) from e
+                raise CogniteAuthorizationError(
+                    message=msg,
+                    code=e.code,
+                    x_request_id=e.x_request_id,
+                    cluster=self._config.cdf_cluster,
+                    project=self._config.project,
+                ) from e
             raise
 
         return self._upload_bytes(content, res.json())
@@ -819,7 +831,13 @@ class FilesAPI(APIClient):
             if e.code == 403 and "insufficient access rights" in e.message:
                 dsid_notice = " Try to provide a data_set_id." if data_set_id is None else ""
                 msg = f"Could not create a file due to insufficient access rights.{dsid_notice}"
-                raise CogniteAuthorizationError(message=msg, code=e.code, x_request_id=e.x_request_id) from e
+                raise CogniteAuthorizationError(
+                    message=msg,
+                    code=e.code,
+                    x_request_id=e.x_request_id,
+                    cluster=self._config.cdf_cluster,
+                    project=self._config.project,
+                ) from e
             raise
 
         returned_file_metadata = res.json()
@@ -874,7 +892,13 @@ class FilesAPI(APIClient):
             )
         except CogniteAPIError as e:
             if e.code == 403:
-                raise CogniteAuthorizationError(message=e.message, code=e.code, x_request_id=e.x_request_id) from e
+                raise CogniteAuthorizationError(
+                    message=e.message,
+                    code=e.code,
+                    x_request_id=e.x_request_id,
+                    cluster=self._config.cdf_cluster,
+                    project=self._config.project,
+                ) from e
             raise
 
         returned_file_metadata = res.json()["items"][0]
@@ -1102,8 +1126,7 @@ class FilesAPI(APIClient):
         tasks = [(directory, {"id": id}, filepath, headers) for id, filepath in zip(all_ids, filepaths)]
         tasks_summary = execute_tasks(self._process_file_download, tasks, max_workers=self._config.max_workers)
         tasks_summary.raise_compound_exception_if_failed_tasks(
-            task_unwrap_fn=lambda task: id_to_metadata[task[1]["id"]],
-            str_format_element_fn=lambda metadata: metadata.id,
+            task_unwrap_fn=lambda task: id_to_metadata[task[1]["id"]]
         )
 
     def _get_download_link(self, identifier: dict[str, int | str]) -> str:
