@@ -120,23 +120,19 @@ class ThreeDModelsAPI(APIClient):
 
         Examples:
 
-            List 3d models::
+            List 3d models:
 
                 >>> from cognite.client import CogniteClient
                 >>> client = CogniteClient()
                 >>> three_d_model_list = client.three_d.models.list()
 
-            Iterate over 3d models::
+            Iterate over 3d models:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> for three_d_model in client.three_d.models:
                 ...     three_d_model # do something with the 3d model
 
-            Iterate over chunks of 3d models to reduce memory load::
+            Iterate over chunks of 3d models to reduce memory load:
 
-                >>> from cognite.client import CogniteClient
-                >>> client = CogniteClient()
                 >>> for three_d_model in client.three_d.models(chunk_size=50):
                 ...     three_d_model # do something with the 3d model
         """
@@ -223,7 +219,7 @@ class ThreeDModelsAPI(APIClient):
 
         Examples:
 
-            Update 3d model that you have fetched. This will perform a full update of the model::
+            Update 3d model that you have fetched. This will perform a full update of the model:
 
                 >>> from cognite.client import CogniteClient
                 >>> client = CogniteClient()
@@ -231,11 +227,9 @@ class ThreeDModelsAPI(APIClient):
                 >>> three_d_model.name = "New Name"
                 >>> res = client.three_d.models.update(three_d_model)
 
-            Perform a partial update on a 3d model::
+            Perform a partial update on a 3d model:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import ThreeDModelUpdate
-                >>> client = CogniteClient()
                 >>> my_update = ThreeDModelUpdate(id=1).name.set("New Name")
                 >>> res = client.three_d.models.update(my_update)
 
@@ -424,7 +418,7 @@ class ThreeDRevisionsAPI(APIClient):
 
         Examples:
 
-            Update a revision that you have fetched. This will perform a full update of the revision::
+            Update a revision that you have fetched. This will perform a full update of the revision:
 
                 >>> from cognite.client import CogniteClient
                 >>> client = CogniteClient()
@@ -432,11 +426,9 @@ class ThreeDRevisionsAPI(APIClient):
                 >>> revision.status = "New Status"
                 >>> res = client.three_d.revisions.update(model_id=1, item=revision)
 
-            Perform a partial update on a revision, updating the published property and adding a new field to metadata::
+            Perform a partial update on a revision, updating the published property and adding a new field to metadata:
 
-                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import ThreeDModelRevisionUpdate
-                >>> client = CogniteClient()
                 >>> my_update = ThreeDModelRevisionUpdate(id=1).published.set(False).metadata.add({"key": "value"})
                 >>> res = client.three_d.revisions.update(model_id=1, item=my_update)
         """
@@ -766,7 +758,5 @@ class ThreeDAssetMappingAPI(APIClient):
         tasks = [{"url_path": path + "/delete", "json": {"items": chunk}} for chunk in chunks]
         summary = execute_tasks(self._post, tasks, self._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks(
-            task_unwrap_fn=unpack_items_in_payload,
-            task_list_element_unwrap_fn=lambda el: ThreeDAssetMapping._load(el),
-            str_format_element_fn=lambda el: (el.asset_id, el.node_id),
+            task_unwrap_fn=unpack_items_in_payload, task_list_element_unwrap_fn=lambda el: ThreeDAssetMapping._load(el)
         )
