@@ -8,7 +8,6 @@ from cognite.client.data_classes.data_modeling.containers import (
     Container,
     ContainerApply,
     ContainerApplyList,
-    ContainerFilter,
     ContainerList,
     ContainerProperty,
     Index,
@@ -68,6 +67,8 @@ from cognite.client.data_classes.data_modeling.instances import (
     InstancesDeleteResult,
     InstanceSort,
     InstancesResult,
+    InvolvedContainers,
+    InvolvedViews,
     Node,
     NodeApply,
     NodeApplyList,
@@ -103,98 +104,99 @@ from cognite.client.data_classes.data_modeling.views import (
 from cognite.client.data_classes.filters import Filter
 
 __all__ = [
-    "Aggregation",
     "AggregatedValue",
-    "aggregations",
-    "ViewIdentifier",
-    "ViewApply",
-    "ViewApplyList",
-    "PropertyId",
-    "MappedPropertyApply",
-    "VersionedDataModelingId",
-    "DataModelingId",
+    "Aggregation",
+    "Boolean",
+    "CDFExternalIdReference",
+    "ConnectionDefinition",
+    "Constraint",
+    "Container",
+    "ContainerApply",
+    "ContainerApplyList",
+    "ContainerId",
     "ContainerIdentifier",
-    "DataModelIdentifier",
-    "DirectRelation",
-    "Filter",
-    "filters",
-    "DirectRelationReference",
+    "ContainerList",
+    "ContainerProperty",
     "DataModel",
-    "DataModelList",
-    "DataModelsSort",
-    "DataModelFilter",
     "DataModelApply",
     "DataModelApplyList",
-    "ContainerFilter",
-    "ViewFilter",
-    "MappedProperty",
-    "ConnectionDefinition",
-    "SingleHopConnectionDefinition",
+    "DataModelFilter",
+    "DataModelId",
+    "DataModelIdentifier",
+    "DataModelList",
+    "DataModelingId",
+    "DataModelsSort",
+    "Date",
+    "DirectRelation",
+    "DirectRelationReference",
+    "Edge",
+    "EdgeApply",
+    "EdgeApplyList",
+    "EdgeApplyResult",
+    "EdgeApplyResultList",
     "EdgeConnection",
     "EdgeConnectionApply",
+    "EdgeId",
+    "EdgeList",
+    "EdgeListWithCursor",
+    "FileReference",
+    "Filter",
+    "Float32",
+    "Float64",
+    "Index",
+    "InstanceApply",
+    "InstanceSort",
+    "InstancesApply",
+    "InstancesApplyResult",
+    "InstancesDeleteResult",
+    "InstancesResult",
+    "Int32",
+    "Int64",
+    "InvolvedContainers",
+    "InvolvedViews",
+    "Json",
+    "MappedProperty",
+    "MappedPropertyApply",
     "MultiEdgeConnection",
     "MultiEdgeConnectionApply",
     "MultiReverseDirectRelation",
     "MultiReverseDirectRelationApply",
-    "Space",
-    "SpaceList",
-    "SpaceApply",
-    "SpaceApplyList",
-    "View",
-    "ViewList",
-    "Container",
-    "ContainerList",
-    "ContainerApply",
-    "ContainerApplyList",
-    "Index",
-    "Constraint",
-    "ContainerProperty",
-    "CDFExternalIdReference",
-    "RequiresConstraint",
-    "ContainerId",
-    "UniquenessConstraint",
-    "ViewId",
-    "DataModelId",
-    "Text",
-    "Boolean",
-    "Float32",
-    "Float64",
-    "Int32",
-    "Int64",
-    "Timestamp",
-    "Date",
-    "Json",
-    "TimeSeriesReference",
-    "FileReference",
-    "SequenceReference",
-    "PropertyType",
     "Node",
-    "NodeList",
-    "NodeListWithCursor",
     "NodeApply",
+    "NodeApplyList",
     "NodeApplyResult",
     "NodeApplyResultList",
-    "NodeApplyList",
-    "Edge",
-    "EdgeList",
-    "EdgeListWithCursor",
-    "EdgeApply",
-    "EdgeApplyResult",
-    "EdgeApplyResultList",
-    "EdgeApplyList",
-    "InstanceSort",
-    "NodeOrEdgeData",
     "NodeId",
-    "EdgeId",
-    "InstancesApplyResult",
-    "InstancesApply",
-    "InstancesDeleteResult",
-    "InstancesResult",
-    "InstanceApply",
-    "query",
+    "NodeList",
+    "NodeListWithCursor",
+    "NodeOrEdgeData",
+    "PropertyId",
     "PropertyOptions",
-    "TypedEdgeApply",
-    "TypedNodeApply",
-    "TypedNode",
+    "PropertyType",
+    "RequiresConstraint",
+    "SequenceReference",
+    "SingleHopConnectionDefinition",
+    "Space",
+    "SpaceApply",
+    "SpaceApplyList",
+    "SpaceList",
+    "Text",
+    "TimeSeriesReference",
+    "Timestamp",
     "TypedEdge",
+    "TypedEdgeApply",
+    "TypedNode",
+    "TypedNodeApply",
+    "UniquenessConstraint",
+    "VersionedDataModelingId",
+    "View",
+    "ViewApply",
+    "ViewApplyList",
+    "ViewFilter",
+    "ViewId",
+    "ViewIdentifier",
+    "ViewList",
+    "aggregations",
+    "filters",
+    "query",
 ]
