@@ -5,18 +5,20 @@ import datetime
 import json
 import typing
 import warnings
-from collections import defaultdict
+from abc import abstractmethod
+from collections import ChainMap, defaultdict
 from collections.abc import Collection, Iterator, Sequence
 from dataclasses import InitVar, dataclass, fields
 from enum import IntEnum
-from functools import cached_property
+from functools import cached_property, partial
+from types import MappingProxyType
 from typing import (
     TYPE_CHECKING,
     Any,
     ClassVar,
     Literal,
+    NoReturn,
     TypedDict,
-    cast,
     overload,
 )
 
@@ -27,7 +29,7 @@ from cognite.client.data_classes._base import CogniteResource, CogniteResourceLi
 from cognite.client.data_classes.data_modeling import NodeId
 from cognite.client.utils import _json
 from cognite.client.utils._auxiliary import find_duplicates
-from cognite.client.utils._identifier import Identifier
+from cognite.client.utils._identifier import Identifier, InstanceId
 from cognite.client.utils._importing import local_import
 from cognite.client.utils._pandas_helpers import (
     concat_dps_dataframe_list,
@@ -38,6 +40,7 @@ from cognite.client.utils._pandas_helpers import (
 from cognite.client.utils._text import (
     convert_all_keys_to_camel_case,
     convert_all_keys_to_snake_case,
+    iterable_to_case,
     to_camel_case,
     to_snake_case,
 )
@@ -79,11 +82,14 @@ Aggregate = Literal[
     "duration_uncertain",
     "interpolation",
     "max",
+    "max_datapoint",
     "min",
+    "min_datapoint",
     "step_interpolation",
     "sum",
     "total_variation",
 ]
+_OBJECT_AGGREGATES: frozenset[Literal["maxDatapoint", "minDatapoint"]] = frozenset({"maxDatapoint", "minDatapoint"})
 _INT_AGGREGATES = frozenset(
     {
         "count",
@@ -96,9 +102,12 @@ _INT_AGGREGATES = frozenset(
     }
 )
 ALL_SORTED_DP_AGGS = sorted(typing.get_args(Aggregate))
+ALL_SORTED_NUMERIC_DP_AGGS = [agg for agg in ALL_SORTED_DP_AGGS if agg not in ("min_datapoint", "max_datapoint")]
 
 
-def numpy_dtype_fix(element: np.float64 | str) -> float | str:
+def numpy_dtype_fix(
+    element: np.float64 | str | MaxOrMinDatapoint, camel_case: bool = False
+) -> float | str | dict[str, int | float | str]:
     try:
         # Using .item() on numpy scalars gives us vanilla python types:
         return element.item()  # type: ignore [union-attr]
@@ -106,6 +115,8 @@ def numpy_dtype_fix(element: np.float64 | str) -> float | str:
         # Return no-op as array contains just references to vanilla python objects:
         if isinstance(element, str):
             return element
+        elif isinstance(element, MaxOrMinDatapoint):
+            return element.dump(camel_case=camel_case)
         raise
 
 
@@ -117,6 +128,118 @@ class StatusCode(IntEnum):
     Bad = 0x80000000  # aka 1 << 31 aka 2147483648
 
 
+@dataclass(slots=True, frozen=True)
+class MaxOrMinDatapoint:
+    @abstractmethod
+    def dump(self, camel_case: bool = True) -> dict[str, Any]: ...
+
+    @classmethod
+    @abstractmethod
+    def _load(cls, dct: dict[str, Any]) -> Self: ...
+
+
+@dataclass(slots=True, frozen=True)
+class MinDatapoint(MaxOrMinDatapoint):
+    timestamp: int
+    value: float
+
+    @property
+    def status_code(self) -> NoReturn:
+        raise AttributeError(
+            "'MinDatapoint' object has no attribute 'status_code'. Tip: fetch using `include_status=True`."
+        )
+
+    @property
+    def status_symbol(self) -> NoReturn:
+        raise AttributeError(
+            "'MinDatapoint' object has no attribute 'status_symbol'. Tip: fetch using `include_status=True`."
+        )
+
+    @classmethod
+    def _load(cls, dct: dict[str, Any]) -> Self:
+        assert "statusCode" not in dct
+        return cls(dct["timestamp"], dct["value"])
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        return {"timestamp": self.timestamp, "value": self.value}
+
+
+@dataclass(slots=True, frozen=True)
+class MinDatapointWithStatus(MinDatapoint):
+    status_code: int  # type: ignore [assignment]
+    status_symbol: str  # type: ignore [assignment]
+
+    @classmethod
+    def _load(cls, dct: dict[str, Any]) -> Self:
+        return cls(dct["timestamp"], dct["value"], dct["statusCode"], dct["statusSymbol"])
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        return {
+            "timestamp": self.timestamp,
+            "value": self.value,
+            "statusCode" if camel_case else "status_code": self.status_code,
+            "statusSymbol" if camel_case else "status_symbol": self.status_symbol,
+        }
+
+
+@dataclass(slots=True, frozen=True)
+class MaxDatapoint(MaxOrMinDatapoint):
+    timestamp: int
+    value: float
+
+    @property
+    def status_code(self) -> NoReturn:
+        raise AttributeError(
+            "'MaxDatapoint' object has no attribute 'status_code'. Tip: fetch using `include_status=True`."
+        )
+
+    @property
+    def status_symbol(self) -> NoReturn:
+        raise AttributeError(
+            "'MaxDatapoint' object has no attribute 'status_symbol'. Tip: fetch using `include_status=True`."
+        )
+
+    @classmethod
+    def _load(cls, dct: dict[str, Any]) -> Self:
+        assert "statusCode" not in dct
+        return cls(dct["timestamp"], dct["value"])
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        return {"timestamp": self.timestamp, "value": self.value}
+
+
+@dataclass(slots=True, frozen=True)
+class MaxDatapointWithStatus(MaxDatapoint):
+    status_code: int  # type: ignore [assignment]
+    status_symbol: str  # type: ignore [assignment]
+
+    @classmethod
+    def _load(cls, dct: dict[str, Any]) -> Self:
+        return cls(dct["timestamp"], dct["value"], dct["statusCode"], dct["statusSymbol"])
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        return {
+            "timestamp": self.timestamp,
+            "value": self.value,
+            "statusCode" if camel_case else "status_code": self.status_code,
+            "statusSymbol" if camel_case else "status_symbol": self.status_symbol,
+        }
+
+
+def _select_min_or_max_datapoint_cls(dct: dict[str, Any], is_minimum: bool) -> type[MaxOrMinDatapoint]:
+    match is_minimum, "statusCode" in dct:
+        case True, True:
+            return MinDatapointWithStatus
+        case True, False:
+            return MinDatapoint
+        case False, True:
+            return MaxDatapointWithStatus
+        case False, False:
+            return MaxDatapoint
+        case _:
+            assert False
+
+
 class _DatapointsPayloadItem(TypedDict, total=False):
     # No field required
     start: int
@@ -139,33 +262,31 @@ class _DatapointsPayload(_DatapointsPayloadItem):
     ignoreUnknownIds: NotRequired[bool]
 
 
-_NOT_SET = object()
-
-
 @dataclass
 class DatapointsQuery:
     """Represent a user request for datapoints for a single time series"""
 
-    OPTIONAL_DICT_KEYS: ClassVar[frozenset[str]] = frozenset(
+    _NOT_SET = object()
+    _API_DEFAULTS: ClassVar[MappingProxyType[str, Any]] = MappingProxyType(
         {
-            "start",
-            "end",
-            "aggregates",
-            "granularity",
-            "timezone",
-            "target_unit",
-            "target_unit_system",
-            "limit",
-            "include_outside_points",
-            "ignore_unknown_ids",
-            "include_status",
-            "ignore_bad_datapoints",
-            "treat_uncertain_as_bad",
+            "start": 0,
+            "end": "now",
+            "aggregates": None,
+            "granularity": None,
+            "timezone": None,
+            "target_unit": None,
+            "target_unit_system": None,
+            "limit": None,
+            "include_outside_points": False,
+            "ignore_unknown_ids": False,
+            "include_status": False,
+            "ignore_bad_datapoints": True,
+            "treat_uncertain_as_bad": True,
         }
     )
     id: InitVar[int | None] = None
     external_id: InitVar[str | None] = None
-    instance_id: InitVar[NodeId | None] = None
+    instance_id: InitVar[NodeId | tuple[str, str] | None] = None
     start: int | str | datetime.datetime = _NOT_SET  # type: ignore [assignment]
     end: int | str | datetime.datetime = _NOT_SET  # type: ignore [assignment]
     aggregates: Aggregate | list[Aggregate] | None = _NOT_SET  # type: ignore [assignment]
@@ -180,9 +301,15 @@ class DatapointsQuery:
     ignore_bad_datapoints: bool = _NOT_SET  # type: ignore [assignment]
     treat_uncertain_as_bad: bool = _NOT_SET  # type: ignore [assignment]
 
-    def __post_init__(self, id: int | None, external_id: str | None, instance_id: NodeId | None) -> None:
+    def __post_init__(
+        self, id: int | None, external_id: str | None, instance_id: NodeId | tuple[str, str] | None
+    ) -> None:
         # Ensure user have just specified one of id/xid:
         self._identifier = Identifier.of_either(id, external_id, instance_id)
+        if instance_id is not None:
+            # dump/load is used in parsing and it loses info of this being a NodeId (loads back as InstanceId). We need
+            # to lookup by identifier to sort (match user queries), and then InstanceId won't compare equal to NodeId:
+            self._identifier = Identifier(NodeId(*self._identifier.as_primitive().as_tuple()))
         # Store the possibly custom granularity (we support more than the API and a translation is done)
         self._original_granularity = self.granularity
 
@@ -196,6 +323,10 @@ class DatapointsQuery:
     def __hash__(self) -> int:
         return hash(id(self))  # See note on __eq__
 
+    @classmethod
+    def valid_from_user_query(cls, query: Self, **settings: Any) -> Self:
+        return cls(**ChainMap(query.dump(), settings, cls._API_DEFAULTS))  # type: ignore [arg-type]
+
     @classmethod
     # TODO: Remove in next major version (require use of DatapointsQuery directly)
     def from_dict(cls, dct: dict[str, Any], id_type: Literal["id", "external_id", "instance_id"]) -> Self:
@@ -205,10 +336,10 @@ class DatapointsQuery:
             # For backwards compatibility we accept identifiers in camel case:
             dct[id_type] = (dct := dct.copy()).pop(arg_name_cc)  # copy to avoid side effects for user's input
 
-        if bad_keys := set(dct) - cls.OPTIONAL_DICT_KEYS - {id_type}:
+        if bad_keys := set(dct) - cls._API_DEFAULTS.keys() - {id_type}:
             raise KeyError(
                 f"Dict provided by argument `{id_type}` included key(s) not understood: {sorted(bad_keys)}. "
-                f"Required key: `{id_type}`. Optional: {list(cls.OPTIONAL_DICT_KEYS)}."
+                f"Required key: `{id_type}`. Optional: {list(cls._API_DEFAULTS)}."
             )
         return cls(**dct)
 
@@ -225,7 +356,7 @@ class DatapointsQuery:
         return self._original_timezone
 
     @original_timezone.setter
-    def original_timezone(self, tz: datetime.timezone | ZoneInfo) -> None:
+    def original_timezone(self, tz: datetime.timezone | ZoneInfo | None) -> None:
         self._original_timezone = tz
 
     @cached_property
@@ -295,7 +426,7 @@ class DatapointsQuery:
         # We need to dump only those fields specifically passed by the user:
         return {
             **self.identifier.as_dict(camel_case=False),
-            **dict((fld.name, val) for fld in fields(self) if (val := getattr(self, fld.name)) is not _NOT_SET),
+            **dict((fld.name, val) for fld in fields(self) if (val := getattr(self, fld.name)) is not self._NOT_SET),
         }
 
     @property
@@ -342,6 +473,7 @@ class LatestDatapointQuery:
     Args:
         id (Optional[int]): The internal ID of the time series to query.
         external_id (Optional[str]): The external ID of the time series to query.
+        instance_id (Optional[NodeId]): The instance ID of the time series to query.
         before (Union[None, int, str, datetime]): Get latest datapoint before this time. None means 'now'.
         target_unit (str | None): The unit_external_id of the data points returned. If the time series does not have a unit_external_id that can be converted to the target_unit, an error will be returned. Cannot be used with target_unit_system.
         target_unit_system (str | None): The unit system of the data points returned. Cannot be used with target_unit.
@@ -352,6 +484,7 @@ class LatestDatapointQuery:
 
     id: InitVar[int | None] = None
     external_id: InitVar[str | None] = None
+    instance_id: InitVar[NodeId | None] = None
     before: None | int | str | datetime.datetime = None
     target_unit: str | None = None
     target_unit_system: str | None = None
@@ -359,9 +492,9 @@ class LatestDatapointQuery:
     ignore_bad_datapoints: bool | None = None
     treat_uncertain_as_bad: bool | None = None
 
-    def __post_init__(self, id: int | None, external_id: str | None) -> None:
+    def __post_init__(self, id: int | None, external_id: str | None, instance_id: NodeId | None) -> None:
         # Ensure user have just specified one of id/xid:
-        object.__setattr__(self, "_identifier", Identifier.of_either(id, external_id))
+        object.__setattr__(self, "_identifier", Identifier.of_either(id, external_id, instance_id))
 
     @property
     def identifier(self) -> Identifier:
@@ -376,7 +509,9 @@ class Datapoint(CogniteResource):
         value (str | float | None): The raw data value. Can be string or numeric.
         average (float | None): The time-weighted average value in the aggregate interval.
         max (float | None): The maximum value in the aggregate interval.
+        max_datapoint (MaxDatapoint | MaxDatapointWithStatus | None): Objects with the maximum values and their timestamps in the aggregate intervals, optionally including status codes and symbols.
         min (float | None): The minimum value in the aggregate interval.
+        min_datapoint (MinDatapoint | MinDatapointWithStatus | None): Objects with the minimum values and their timestamps in the aggregate intervals, optionally including status codes and symbols.
         count (int | None): The number of raw datapoints in the aggregate interval.
         sum (float | None): The sum of the raw datapoints in the aggregate interval.
         interpolation (float | None): The interpolated value at the beginning of the aggregate interval.
@@ -401,7 +536,9 @@ class Datapoint(CogniteResource):
         value: str | float | None = None,
         average: float | None = None,
         max: float | None = None,
+        max_datapoint: MaxDatapoint | MaxDatapointWithStatus | None = None,
         min: float | None = None,
+        min_datapoint: MinDatapoint | MinDatapointWithStatus | None = None,
         count: int | None = None,
         sum: float | None = None,
         interpolation: float | None = None,
@@ -419,11 +556,13 @@ class Datapoint(CogniteResource):
         status_symbol: str | None = None,
         timezone: datetime.timezone | ZoneInfo | None = None,
     ) -> None:
-        self.timestamp = timestamp
+        self.timestamp: int = timestamp  # type: ignore
         self.value = value
         self.average = average
         self.max = max
+        self.max_datapoint = max_datapoint
         self.min = min
+        self.min_datapoint = min_datapoint
         self.count = count
         self.sum = sum
         self.interpolation = interpolation
@@ -443,7 +582,7 @@ class Datapoint(CogniteResource):
 
     def __str__(self) -> str:
         item = self.dump(camel_case=False)
-        item["timestamp"] = convert_and_isoformat_timestamp(cast(int, self.timestamp), self.timezone)
+        item["timestamp"] = convert_and_isoformat_timestamp(self.timestamp, self.timezone)
         return _json.dumps(item, indent=4)
 
     def to_pandas(self, camel_case: bool = False) -> pandas.DataFrame:  # type: ignore[override]
@@ -458,6 +597,10 @@ class Datapoint(CogniteResource):
         pd = local_import("pandas")
 
         dumped = self.dump(camel_case=camel_case)
+        for key in iterable_to_case(["min_datapoint", "max_datapoint"], camel_case):
+            if dp := dumped.get(key):
+                dumped[key] = [dp]  # make pandas treat this dict as a scalar value
+
         timestamp = dumped.pop("timestamp")
         tz = convert_tz_for_pandas(self.timezone)
         return pd.DataFrame(dumped, index=[pd.Timestamp(timestamp, unit="ms", tz=tz)])
@@ -465,6 +608,10 @@ class Datapoint(CogniteResource):
     @classmethod
     def _load(cls, resource: dict[str, Any], cognite_client: CogniteClient | None = None) -> Self:
         instance = super()._load(resource, cognite_client=cognite_client)
+        if isinstance(max_dp := instance.max_datapoint, dict):
+            instance.max_datapoint = _select_min_or_max_datapoint_cls(max_dp, is_minimum=False)._load(max_dp)
+        if isinstance(min_dp := instance.min_datapoint, dict):
+            instance.min_datapoint = _select_min_or_max_datapoint_cls(min_dp, is_minimum=True)._load(min_dp)
         if isinstance(instance.timezone, str):
             with contextlib.suppress(ValueError):  # Dont fail load if invalid
                 instance.timezone = parse_str_timezone(instance.timezone)
@@ -474,6 +621,10 @@ class Datapoint(CogniteResource):
         dumped = super().dump(camel_case=camel_case)
         # Keep value even if None (bad status codes support missing):
         dumped["value"] = self.value  # TODO: What if Datapoint represents one or more aggregates?
+        if self.max_datapoint:
+            dumped["maxDatapoint" if camel_case else "max_datapoint"] = self.max_datapoint.dump(camel_case)
+        if self.min_datapoint:
+            dumped["minDatapoint" if camel_case else "min_datapoint"] = self.min_datapoint.dump(camel_case)
         if include_timezone:
             if self.timezone is not None:
                 dumped["timezone"] = convert_timezone_to_str(self.timezone)
@@ -499,7 +650,9 @@ class DatapointsArray(CogniteResource):
         value: NumpyFloat64Array | NumpyObjArray | None = None,
         average: NumpyFloat64Array | None = None,
         max: NumpyFloat64Array | None = None,
+        max_datapoint: NumpyObjArray | None = None,
         min: NumpyFloat64Array | None = None,
+        min_datapoint: NumpyObjArray | None = None,
         count: NumpyInt64Array | None = None,
         sum: NumpyFloat64Array | None = None,
         interpolation: NumpyFloat64Array | None = None,
@@ -526,11 +679,15 @@ class DatapointsArray(CogniteResource):
         self.unit = unit
         self.unit_external_id = unit_external_id
         self.granularity = granularity
-        self.timestamp = timestamp if timestamp is not None else np.array([], dtype="datetime64[ns]")
+        self.timestamp: NumpyDatetime64NSArray = (
+            timestamp if timestamp is not None else np.array([], dtype="datetime64[ns]")
+        )
         self.value = value
         self.average = average
         self.max = max
+        self.max_datapoint = max_datapoint
         self.min = min
+        self.min_datapoint = min_datapoint
         self.count = count
         self.sum = sum
         self.interpolation = interpolation
@@ -683,9 +840,12 @@ class DatapointsArray(CogniteResource):
             return self._slice(item)
         attrs, arrays = self._data_fields()
         timestamp = arrays[0][item].item() // 1_000_000
-        data: dict[str, float | str | None] = {
+        data: dict[str, float | str | dict | None] = {
             attr: numpy_dtype_fix(arr[item]) for attr, arr in zip(attrs[1:], arrays[1:])
         }
+        for key in ("min_datapoint", "max_datapoint"):
+            if key in data:
+                data[key] = getattr(self, key)[item]
         if self.status_code is not None:
             data.update(status_code=self.status_code[item], status_symbol=self.status_symbol[item])  # type: ignore [index]
         if self.null_timestamps and timestamp in self.null_timestamps:
@@ -723,13 +883,17 @@ class DatapointsArray(CogniteResource):
         # Let's not create a single Datapoint more than we have too:
         for i, row in enumerate(zip(*arrays)):
             timestamp = row[0].item() // 1_000_000
-            data: dict[str, float | str | None] = dict(zip(attrs[1:], map(numpy_dtype_fix, row[1:])))
+            data: dict[str, Any] = dict(zip(map(to_camel_case, attrs[1:]), map(numpy_dtype_fix, row[1:])))
+            data.update(timestamp=timestamp, timezone=self.timezone)
             if self.status_code is not None:
-                data.update(status_code=self.status_code[i], status_symbol=self.status_symbol[i])  # type: ignore [index]
+                data.update(statusCode=self.status_code[i], statusSymbol=self.status_symbol[i])  # type: ignore [index]
             if self.null_timestamps and timestamp in self.null_timestamps:
                 data["value"] = None
-
-            yield Datapoint(timestamp=timestamp, **data, timezone=self.timezone)  # type: ignore [arg-type]
+            if self.min_datapoint is not None:
+                data["minDatapoint"] = self.min_datapoint[i]
+            if self.max_datapoint is not None:
+                data["maxDatapoint"] = self.max_datapoint[i]
+            yield Datapoint._load(data)
 
     def _data_fields(self) -> tuple[list[str], list[npt.NDArray]]:
         # Note: Does not return status-related fields
@@ -776,7 +940,9 @@ class DatapointsArray(CogniteResource):
             dumped["timezone"] = str(self.timezone)
         if self.instance_id:
             dumped["instance_id"] = self.instance_id.dump(camel_case=camel_case, include_instance_type=False)
-        datapoints = [dict(zip(attrs, map(numpy_dtype_fix, row))) for row in zip(*arrays)]
+
+        convert_fn = partial(numpy_dtype_fix, camel_case=camel_case)
+        datapoints = [dict(zip(attrs, map(convert_fn, row))) for row in zip(*arrays)]
 
         if self.status_code is not None or self.status_symbol is not None:
             if (
@@ -787,7 +953,7 @@ class DatapointsArray(CogniteResource):
                 raise ValueError("The number of status codes/symbols does not match the number of datapoints")
 
             for dp, code, symbol in zip(datapoints, map(numpy_dtype_fix, self.status_code), self.status_symbol):
-                dp["status"] = {"code": code, "symbol": symbol}  # type: ignore [assignment]
+                dp["status"] = {"code": code, "symbol": symbol}  # type: ignore [dict-item]
 
         # When we're dealing with datapoints with bad status codes, NaN might be either one of [<missing>, nan]:
         if self.null_timestamps:
@@ -838,6 +1004,11 @@ class DatapointsArray(CogniteResource):
             identifier + include_aggregate_name * f"|{agg}" + include_granularity_name * f"|{self.granularity}"
             for agg in agg_names
         ]
+        # We need special handling for object aggregates:
+        for i, agg in enumerate(agg_names):
+            if agg in ("min_datapoint", "max_datapoint"):
+                arrays[i] = np.array([dp.dump(camel_case=False) for dp in arrays[i]], dtype=np.object_)
+
         # Since columns might contain duplicates, we can't instantiate from dict as only the
         # last key (array/column) would be kept:
         (df := pd.DataFrame(dict(enumerate(arrays)), index=idx, copy=False)).columns = aggregate_columns
@@ -860,7 +1031,9 @@ class Datapoints(CogniteResource):
         value (SequenceNotStr[str] | Sequence[float] | None): The raw data values. Can be string or numeric.
         average (list[float] | None): The time-weighted average values per aggregate interval.
         max (list[float] | None): The maximum values per aggregate interval.
+        max_datapoint (list[MaxDatapoint] | list[MaxDatapointWithStatus] | None): Objects with the maximum values and their timestamps in the aggregate intervals, optionally including status codes and symbols.
         min (list[float] | None): The minimum values per aggregate interval.
+        min_datapoint (list[MinDatapoint] | list[MinDatapointWithStatus] | None): Objects with the minimum values and their timestamps in the aggregate intervals, optionally including status codes and symbols.
         count (list[int] | None): The number of raw datapoints per aggregate interval.
         sum (list[float] | None): The sum of the raw datapoints per aggregate interval.
         interpolation (list[float] | None): The interpolated values at the beginning of each the aggregate interval.
@@ -894,7 +1067,9 @@ class Datapoints(CogniteResource):
         value: SequenceNotStr[str] | Sequence[float] | None = None,
         average: list[float] | None = None,
         max: list[float] | None = None,
+        max_datapoint: list[MaxDatapoint] | list[MaxDatapointWithStatus] | None = None,
         min: list[float] | None = None,
+        min_datapoint: list[MinDatapoint] | list[MinDatapointWithStatus] | None = None,
         count: list[int] | None = None,
         sum: list[float] | None = None,
         interpolation: list[float] | None = None,
@@ -921,11 +1096,13 @@ class Datapoints(CogniteResource):
         self.unit = unit
         self.unit_external_id = unit_external_id
         self.granularity = granularity
-        self.timestamp = timestamp or []  # Needed in __len__
+        self.timestamp: list[int] = timestamp or []  # type: ignore
         self.value = value
         self.average = average
         self.max = max
+        self.max_datapoint = max_datapoint
         self.min = min
+        self.min_datapoint = min_datapoint
         self.count = count
         self.sum = sum
         self.interpolation = interpolation
@@ -1078,7 +1255,10 @@ class Datapoints(CogniteResource):
                 data_lists.append(data)
                 continue  # Keep string (object) column non-numeric
 
-            data = pd.to_numeric(data, errors="coerce")  # Avoids object dtype for missing aggs
+            if to_camel_case(attr) in _OBJECT_AGGREGATES:
+                data_lists.append([v.dump(camel_case=False) for v in data])
+                continue
+            data = pd.to_numeric(data, errors="coerce")  # Avoids object dtype for missing agg values
             if to_camel_case(attr) in _INT_AGGREGATES:
                 data_lists.append(data.astype("int64"))
             else:
@@ -1142,6 +1322,12 @@ class Datapoints(CogniteResource):
         if (status := data_lists.pop("status", None)) is not None:
             data_lists["status_code"] = [s["code"] for s in status]
             data_lists["status_symbol"] = [s["symbol"] for s in status]
+        if min_dp := data_lists.get("minDatapoint"):
+            min_load_cls = _select_min_or_max_datapoint_cls(min_dp[0], is_minimum=True)
+            data_lists["minDatapoint"] = list(map(min_load_cls._load, min_dp))
+        if max_dp := data_lists.get("maxDatapoint"):
+            max_load_cls = _select_min_or_max_datapoint_cls(max_dp[0], is_minimum=False)
+            data_lists["maxDatapoint"] = list(map(max_load_cls._load, max_dp))
 
         for key, data in data_lists.items():
             snake_key = to_snake_case(key)
@@ -1198,13 +1384,13 @@ class Datapoints(CogniteResource):
         for i in range(len(self)):
             dp_args: dict[str, Any] = {"timezone": self.timezone}
             for attr, value in fields:
-                dp_args[attr] = value[i]
+                dp_args[to_camel_case(attr)] = value[i]
             if self.status_code is not None:
                 dp_args.update(
                     statusCode=self.status_code[i],
                     statusSymbol=self.status_symbol[i],  # type: ignore [index]
                 )
-            new_dps_objects.append(Datapoint.load(dp_args))
+            new_dps_objects.append(Datapoint._load(dp_args))
         self.__datapoint_objects = new_dps_objects
         return self.__datapoint_objects
 
@@ -1241,17 +1427,22 @@ class DatapointsArrayList(CogniteResourceList[DatapointsArray]):
         # Fix what happens for duplicated identifiers:
         ids = [dps.id for dps in self if dps.id is not None]
         xids = [dps.external_id for dps in self if dps.external_id is not None]
+        inst_ids = [dps.instance_id for dps in self if dps.instance_id is not None]
         dupe_ids, id_dct = find_duplicates(ids), defaultdict(list)
         dupe_xids, xid_dct = find_duplicates(xids), defaultdict(list)
+        dupe_inst_ids, inst_id_dct = find_duplicates(inst_ids), defaultdict(list)
 
         for dps in self:
             if (id_ := dps.id) is not None and id_ in dupe_ids:
                 id_dct[id_].append(dps)
             if (xid := dps.external_id) is not None and xid in dupe_xids:
                 xid_dct[xid].append(dps)
+            if (inst_id := dps.instance_id) is not None and inst_id in dupe_inst_ids:
+                inst_id_dct[xid].append(dps)
 
         self._id_to_item.update(id_dct)
         self._external_id_to_item.update(xid_dct)
+        self._instance_id_to_item.update(inst_id_dct)
 
     def concat_duplicate_ids(self) -> None:
         """
@@ -1296,6 +1487,7 @@ class DatapointsArrayList(CogniteResourceList[DatapointsArray]):
         self,
         id: int | None = None,
         external_id: str | None = None,
+        instance_id: NodeId | tuple[str, str] | None = None,
     ) -> DatapointsArray | list[DatapointsArray] | None:
         """Get a specific DatapointsArray from this list by id or external_id.
 
@@ -1305,12 +1497,13 @@ class DatapointsArrayList(CogniteResourceList[DatapointsArray]):
         Args:
             id (int | None): The id of the item(s) to get.
             external_id (str | None): The external_id of the item(s) to get.
+            instance_id (NodeId | tuple[str, str] | None): The instance_id of the item(s) to get.
 
         Returns:
             DatapointsArray | list[DatapointsArray] | None: The requested item(s)
         """
         # TODO: Question, can we type annotate without specifying the function?
-        return super().get(id, external_id)
+        return super().get(id, external_id, instance_id)
 
     def __str__(self) -> str:
         return _json.dumps(self.dump(convert_timestamps=True), indent=4)
@@ -1363,24 +1556,30 @@ class DatapointsList(CogniteResourceList[Datapoints]):
         # Fix what happens for duplicated identifiers:
         ids = [dps.id for dps in self if dps.id is not None]
         xids = [dps.external_id for dps in self if dps.external_id is not None]
+        inst_ids = [dps.instance_id for dps in self if dps.instance_id is not None]
         dupe_ids, id_dct = find_duplicates(ids), defaultdict(list)
         dupe_xids, xid_dct = find_duplicates(xids), defaultdict(list)
+        dupe_inst_ids, inst_id_dct = find_duplicates(inst_ids), defaultdict(list)
 
         for dps in self:
             if (id_ := dps.id) is not None and id_ in dupe_ids:
                 id_dct[id_].append(dps)
             if (xid := dps.external_id) is not None and xid in dupe_xids:
                 xid_dct[xid].append(dps)
+            if (inst_id := dps.instance_id) is not None and inst_id in dupe_inst_ids:
+                inst_id_dct[xid].append(dps)
 
         self._id_to_item.update(id_dct)
         self._external_id_to_item.update(xid_dct)
+        self._instance_id_to_item.update(inst_id_dct)
 
     def get(  # type: ignore [override]
         self,
         id: int | None = None,
         external_id: str | None = None,
+        instance_id: InstanceId | tuple[str, str] | None = None,
     ) -> Datapoints | list[Datapoints] | None:
-        """Get a specific Datapoints from this list by id or external_id.
+        """Get a specific Datapoints from this list by id, external_id or instance_id.
 
         Note:
             For duplicated time series, returns a list of Datapoints.
@@ -1388,12 +1587,13 @@ class DatapointsList(CogniteResourceList[Datapoints]):
         Args:
             id (int | None): The id of the item(s) to get.
             external_id (str | None): The external_id of the item(s) to get.
+            instance_id (InstanceId | tuple[str, str] | None): The instance_id of the item(s) to get.
 
         Returns:
             Datapoints | list[Datapoints] | None: The requested item(s)
         """
         # TODO: Question, can we type annotate without specifying the function?
-        return super().get(id, external_id)
+        return super().get(id, external_id, instance_id)
 
     def __str__(self) -> str:
         dumped = self.dump()
