@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import time
 from abc import ABC
-from typing import TYPE_CHECKING, Any, Literal, TypeAlias, cast
+from typing import TYPE_CHECKING, Any, Literal, Protocol, TypeAlias, cast
 
 from cognite.client._constants import DEFAULT_LIMIT_READ
 from cognite.client.data_classes._base import (
@@ -12,6 +12,7 @@ from cognite.client.data_classes._base import (
     CogniteResponse,
     ExternalIDTransformerMixin,
     IdTransformerMixin,
+    InternalIdTransformerMixin,
     WriteableCogniteResource,
     WriteableCogniteResourceList,
 )
@@ -21,11 +22,59 @@ from cognite.client.utils._time import ms_to_datetime
 if TYPE_CHECKING:
     from cognite.client import CogniteClient
 
-RunTime: TypeAlias = Literal["py38", "py39", "py310", "py311"]
+RunTime: TypeAlias = Literal["py39", "py310", "py311"]
 FunctionStatus: TypeAlias = Literal["Queued", "Deploying", "Ready", "Failed"]
 HANDLER_FILE_NAME = "handler.py"
 
 
+class FunctionHandle(Protocol):
+    """The function handle.
+
+    This is the function that will be called when the function is executed. The function
+    must be named "handle" and can take any of the following named only arguments:
+
+    Args:
+        client (CogniteClient | None): Cognite client.
+        data (dict[str, object] | None): Input data to the function.
+        secrets (dict[str, str] | None): Secrets passed to the function.
+        function_call_info (dict[str, object] | None): Function call information.
+
+    Example:
+        .. code-block:: python
+
+            def handle(
+                client: CogniteClient | None = None,
+                data: dict[str, object] | None = None,
+            ) -> object:
+                # Do something with the data
+                return {"result": "success"}
+
+    Returns:
+        object: Return value of the function. Any JSON serializable object is allowed.
+    """
+
+    def __call__(
+        self,
+        *,
+        client: CogniteClient | None = None,
+        data: dict[str, object] | None = None,
+        secrets: dict[str, str] | None = None,
+        function_call_info: dict[str, object] | None = None,
+    ) -> object:
+        """Function handle protocol.
+
+        Args:
+            client (CogniteClient | None): Cognite client.
+            data (dict[str, object] | None): Input data to the function.
+            secrets (dict[str, str] | None): Secrets passed to the function.
+            function_call_info (dict[str, object] | None): Function call information.
+
+        Returns:
+            object: Return value of the function. Any JSON serializable object is allowed.
+        """
+        ...
+
+
 class FunctionCore(WriteableCogniteResource["FunctionWrite"], ABC):
     """A representation of a Cognite Function.
 
@@ -40,7 +89,7 @@ class FunctionCore(WriteableCogniteResource["FunctionWrite"], ABC):
         env_vars (dict[str, str] | None): User specified environment variables on the function ((key, value) pairs).
         cpu (float | None): Number of CPU cores per function. Allowed range and default value are given by the `limits endpoint. <https://developer.cognite.com/api#tag/Functions/operation/functionsLimits>`_, and None translates to the API default. On Azure, only the default value is used.
         memory (float | None): Memory per function measured in GB. Allowed range and default value are given by the `limits endpoint. <https://developer.cognite.com/api#tag/Functions/operation/functionsLimits>`_, and None translates to the API default. On Azure, only the default value is used.
-        runtime (str | None): Runtime of the function. Allowed values are ["py38", "py39","py310", "py311"]. The runtime "py38" resolves to the latest version of the Python 3.8 series.
+        runtime (str | None): Runtime of the function. Allowed values are ["py39","py310", "py311"]. The runtime "py311" resolves to the latest version of the Python 3.11 series.
         metadata (dict[str, str] | None): Metadata associated with a function as a set of key:value pairs.
     """
 
@@ -96,7 +145,7 @@ class Function(FunctionCore):
         env_vars (dict[str, str] | None): User specified environment variables on the function ((key, value) pairs).
         cpu (float | None): Number of CPU cores per function. Allowed range and default value are given by the `limits endpoint. <https://developer.cognite.com/api#tag/Functions/operation/functionsLimits>`_, and None translates to the API default. On Azure, only the default value is used.
         memory (float | None): Memory per function measured in GB. Allowed range and default value are given by the `limits endpoint. <https://developer.cognite.com/api#tag/Functions/operation/functionsLimits>`_, and None translates to the API default. On Azure, only the default value is used.
-        runtime (str | None): Runtime of the function. Allowed values are ["py38", "py39","py310", "py311"]. The runtime "py38" resolves to the latest version of the Python 3.8 series.
+        runtime (str | None): Runtime of the function. Allowed values are ["py39","py310", "py311"]. The runtime "py311" resolves to the latest version of the Python 3.11s series.
         runtime_version (str | None): The complete specification of the function runtime with major, minor and patch version numbers.
         metadata (dict[str, str] | None): Metadata associated with a function as a set of key:value pairs.
         error (dict | None): Dictionary with keys "message" and "trace", which is populated if deployment fails.
@@ -169,11 +218,11 @@ class Function(FunctionCore):
             metadata=self.metadata,
         )
 
-    def call(self, data: dict | None = None, wait: bool = True) -> FunctionCall:
+    def call(self, data: dict[str, object] | None = None, wait: bool = True) -> FunctionCall:
         """`Call this particular function. <https://docs.cognite.com/api/v1/#operation/postFunctionsCall>`_
 
         Args:
-            data (dict | None): Input data to the function (JSON serializable). This data is passed deserialized into the function through one of the arguments called data. **WARNING:** Secrets or other confidential information should not be passed via this argument. There is a dedicated `secrets` argument in FunctionsAPI.create() for this purpose.
+            data (dict[str, object] | None): Input data to the function (JSON serializable). This data is passed deserialized into the function through one of the arguments called data. **WARNING:** Secrets or other confidential information should not be passed via this argument. There is a dedicated `secrets` argument in FunctionsAPI.create() for this purpose.
             wait (bool): Wait until the function call is finished. Defaults to True.
 
         Returns:
@@ -260,7 +309,7 @@ class FunctionWrite(FunctionCore):
         env_vars (dict[str, str] | None): User specified environment variables on the function ((key, value) pairs).
         cpu (float | None): Number of CPU cores per function. Allowed range and default value are given by the `limits endpoint. <https://developer.cognite.com/api#tag/Functions/operation/functionsLimits>`_, and None translates to the API default. On Azure, only the default value is used.
         memory (float | None): Memory per function measured in GB. Allowed range and default value are given by the `limits endpoint. <https://developer.cognite.com/api#tag/Functions/operation/functionsLimits>`_, and None translates to the API default. On Azure, only the default value is used.
-        runtime (RunTime | None): Runtime of the function. Allowed values are ["py38", "py39","py310", "py311"]. The runtime "py38" resolves to the latest version of the Python 3.8 series.
+        runtime (RunTime | None): Runtime of the function. Allowed values are ["py39","py310", "py311"]. The runtime "py311" resolves to the latest version of the Python 3.11 series.
         metadata (dict[str, str] | None): Metadata associated with a function as a set of key:value pairs.
         index_url (str | None): Specify a different python package index, allowing for packages published in private repositories. Supports basic HTTP authentication as described in pip basic authentication. See the documentation for additional information related to the security risks of using this option.
         extra_index_urls (list[str] | None): Extra package index URLs to use when building the function, allowing for packages published in private repositories. Supports basic HTTP authentication as described in pip basic authentication. See the documentation for additional information related to the security risks of using this option.
@@ -528,7 +577,10 @@ class FunctionScheduleWriteList(CogniteResourceList[FunctionScheduleWrite]):
     _RESOURCE = FunctionScheduleWrite
 
 
-class FunctionSchedulesList(WriteableCogniteResourceList[FunctionScheduleWrite, FunctionSchedule]):
+class FunctionSchedulesList(
+    WriteableCogniteResourceList[FunctionScheduleWrite, FunctionSchedule],
+    InternalIdTransformerMixin,
+):
     _RESOURCE = FunctionSchedule
 
     def as_write(self) -> FunctionScheduleWriteList:
@@ -590,11 +642,11 @@ class FunctionCall(CogniteResource):
         self.function_id: int = function_id  # type: ignore
         self._cognite_client = cast("CogniteClient", cognite_client)
 
-    def get_response(self) -> dict | None:
+    def get_response(self) -> dict[str, object] | None:
         """Retrieve the response from this function call.
 
         Returns:
-            dict | None: Response from the function call.
+            dict[str, object] | None: Response from the function call.
         """
         call_id, function_id = self._get_identifiers_or_raise(self.id, self.function_id)
         return self._cognite_client.functions.calls.get_response(call_id=call_id, function_id=function_id)
@@ -631,7 +683,7 @@ class FunctionCall(CogniteResource):
             time.sleep(1.0)
 
 
-class FunctionCallList(CogniteResourceList[FunctionCall]):
+class FunctionCallList(CogniteResourceList[FunctionCall], InternalIdTransformerMixin):
     _RESOURCE = FunctionCall
 
 
@@ -684,7 +736,7 @@ class FunctionsLimits(CogniteResponse):
         timeout_minutes (int): Timeout of each function call.
         cpu_cores (dict[str, float]): The number of CPU cores per function execution (i.e. function call).
         memory_gb (dict[str, float]): The amount of available memory in GB per function execution (i.e. function call).
-        runtimes (list[str]): Available runtimes. For example, "py39" translates to the latest version of the Python 3.9.x series.
+        runtimes (list[str]): Available runtimes. For example, "py311" translates to the latest version of the Python 3.11 series.
         response_size_mb (int | None): Maximum response size of function calls.
     """
 
