@@ -6,6 +6,10 @@ from typing import Any
 from unittest.mock import MagicMock
 
 from cognite.client import CogniteClient
+from cognite.client._api.agents import AgentsAPI
+from cognite.client._api.ai import AIAPI
+from cognite.client._api.ai.tools import AIToolsAPI
+from cognite.client._api.ai.tools.documents import AIDocumentsAPI
 from cognite.client._api.annotations import AnnotationsAPI
 from cognite.client._api.assets import AssetsAPI
 from cognite.client._api.data_modeling import DataModelingAPI
@@ -14,6 +18,7 @@ from cognite.client._api.data_modeling.data_models import DataModelsAPI
 from cognite.client._api.data_modeling.graphql import DataModelingGraphQLAPI
 from cognite.client._api.data_modeling.instances import InstancesAPI
 from cognite.client._api.data_modeling.spaces import SpacesAPI
+from cognite.client._api.data_modeling.statistics import SpaceStatisticsAPI, StatisticsAPI
 from cognite.client._api.data_modeling.views import ViewsAPI
 from cognite.client._api.data_sets import DataSetsAPI
 from cognite.client._api.datapoints import DatapointsAPI
@@ -38,10 +43,19 @@ from cognite.client._api.hosted_extractors.sources import SourcesAPI
 from cognite.client._api.iam import IAMAPI, GroupsAPI, SecurityCategoriesAPI, SessionsAPI, TokenAPI
 from cognite.client._api.labels import LabelsAPI
 from cognite.client._api.postgres_gateway import PostgresGatewaysAPI
+from cognite.client._api.postgres_gateway.tables import TablesAPI as PostgresTablesAPI
 from cognite.client._api.postgres_gateway.users import UsersAPI as PostgresUsersAPI
 from cognite.client._api.raw import RawAPI, RawDatabasesAPI, RawRowsAPI, RawTablesAPI
 from cognite.client._api.relationships import RelationshipsAPI
 from cognite.client._api.sequences import SequencesAPI, SequencesDataAPI
+from cognite.client._api.simulators import SimulatorsAPI
+from cognite.client._api.simulators.integrations import SimulatorIntegrationsAPI
+from cognite.client._api.simulators.logs import SimulatorLogsAPI
+from cognite.client._api.simulators.models import SimulatorModelsAPI
+from cognite.client._api.simulators.models_revisions import SimulatorModelRevisionsAPI
+from cognite.client._api.simulators.routine_revisions import SimulatorRoutineRevisionsAPI
+from cognite.client._api.simulators.routines import SimulatorRoutinesAPI
+from cognite.client._api.simulators.runs import SimulatorRunsAPI
 from cognite.client._api.synthetic_time_series import SyntheticDatapointsAPI
 from cognite.client._api.templates import (
     TemplateGroupsAPI,
@@ -94,6 +108,11 @@ class CogniteClientMock(MagicMock):
         #   - Add spacing above and below
         #   - Use `spec=MyAPI` only for "top level"
         #   - Use `spec_set=MyNestedAPI` for all nested APIs
+        self.ai = MagicMock(spec=AIAPI)
+        self.ai.tools = MagicMock(spec=AIToolsAPI)
+        self.ai.tools.documents = MagicMock(spec_set=AIDocumentsAPI)
+
+        self.agents = MagicMock(spec_set=AgentsAPI)
         self.annotations = MagicMock(spec_set=AnnotationsAPI)
         self.assets = MagicMock(spec_set=AssetsAPI)
 
@@ -104,6 +123,8 @@ class CogniteClientMock(MagicMock):
         self.data_modeling.views = MagicMock(spec_set=ViewsAPI)
         self.data_modeling.instances = MagicMock(spec_set=InstancesAPI)
         self.data_modeling.graphql = MagicMock(spec_set=DataModelingGraphQLAPI)
+        self.data_modeling.statistics = MagicMock(spec=StatisticsAPI)
+        self.data_modeling.statistics.spaces = MagicMock(spec_set=SpaceStatisticsAPI)
 
         self.data_sets = MagicMock(spec_set=DataSetsAPI)
 
@@ -141,7 +162,17 @@ class CogniteClientMock(MagicMock):
 
         self.relationships = MagicMock(spec_set=RelationshipsAPI)
 
+        self.simulators = MagicMock(spec=SimulatorsAPI)
+        self.simulators.integrations = MagicMock(spec_set=SimulatorIntegrationsAPI)
+        self.simulators.models = MagicMock(spec=SimulatorModelsAPI)
+        self.simulators.models.revisions = MagicMock(spec_set=SimulatorModelRevisionsAPI)
+        self.simulators.runs = MagicMock(spec_set=SimulatorRunsAPI)
+        self.simulators.routines = MagicMock(spec=SimulatorRoutinesAPI)
+        self.simulators.routines.revisions = MagicMock(spec_set=SimulatorRoutineRevisionsAPI)
+        self.simulators.logs = MagicMock(spec_set=SimulatorLogsAPI)
+
         self.sequences = MagicMock(spec=SequencesAPI)
+        self.sequences.rows = MagicMock(spec_set=SequencesDataAPI)
         self.sequences.data = MagicMock(spec_set=SequencesDataAPI)
 
         self.hosted_extractors = MagicMock(spec=HostedExtractorsAPI)
@@ -152,6 +183,7 @@ class CogniteClientMock(MagicMock):
 
         self.postgres_gateway = MagicMock(spec=PostgresGatewaysAPI)
         self.postgres_gateway.users = MagicMock(spec_set=PostgresUsersAPI)
+        self.postgres_gateway.tables = MagicMock(spec_set=PostgresTablesAPI)
 
         self.templates = MagicMock(spec=TemplatesAPI)
         self.templates.groups = MagicMock(spec_set=TemplateGroupsAPI)
