@@ -5,12 +5,15 @@ import functools
 import math
 import numbers
 import re
+import threading
 import time
 from abc import ABC, abstractmethod
+from collections.abc import Callable
 from contextlib import suppress
 from datetime import datetime, timedelta, timezone
+from functools import wraps
 from itertools import pairwise
-from typing import TYPE_CHECKING, cast, overload
+from typing import TYPE_CHECKING, ParamSpec, TypeVar, cast, overload
 from zoneinfo import ZoneInfo, ZoneInfoNotFoundError
 
 from cognite.client.utils._importing import local_import
@@ -21,6 +24,10 @@ if TYPE_CHECKING:
 
     import pandas
 
+
+_T = TypeVar("_T")
+_P = ParamSpec("_P")
+
 UNIT_IN_MS_WITHOUT_WEEK = {"s": 1000, "m": 60000, "h": 3600000, "d": 86400000}
 UNIT_IN_MS = {**UNIT_IN_MS_WITHOUT_WEEK, "w": 604800000}
 VARIABLE_LENGTH_UNITS = {"month", "quarter", "year"}
@@ -228,32 +235,45 @@ def granularity_to_ms(granularity: str, as_unit: bool = False) -> int:
     return ms
 
 
-def time_ago_to_ms(time_ago_string: str) -> int:
-    """Returns millisecond representation of time-ago string"""
+def time_shift_to_ms(time_ago_string: str) -> int:
+    """Returns millisecond representation of time-shift string"""
     if time_ago_string == "now":
         return 0
-    ms = time_string_to_ms(r"(\d+)({})-ago", time_ago_string, UNIT_IN_MS)
+    ms = time_string_to_ms(r"(\d+)({})-(?:ago|ahead)", time_ago_string, UNIT_IN_MS)
     if ms is None:
         raise ValueError(
-            f"Invalid time-ago format: `{time_ago_string}`. Must be on format <integer>(s|m|h|d|w)-ago or 'now'. "
-            "E.g. '3d-ago' or '1w-ago'."
+            f"Invalid time-shift format: `{time_ago_string}`. Must be on format <integer>(s|m|h|d|w)-(ago|ahead) or 'now'. "
+            "E.g. '3d-ago' or '1w-ahead'."
         )
+    if "ahead" in time_ago_string:
+        return -ms
     return ms
 
 
 def timestamp_to_ms(timestamp: int | float | str | datetime) -> int:
-    """Returns the ms representation of some timestamp given by milliseconds, time-ago format or datetime object
+    """Returns the ms representation of some timestamp given by milliseconds, time-shift format or datetime object
 
     Args:
         timestamp (int | float | str | datetime): Convert this timestamp to ms.
 
     Returns:
         int: Milliseconds since epoch representation of timestamp
+
+    Examples:
+
+        Gets the millisecond representation of a timestamp:
+
+            >>> from cognite.client.utils import timestamp_to_ms
+            >>> from datetime import datetime
+            >>> timestamp_to_ms(datetime(2021, 1, 7, 12, 0, 0))
+            >>> timestamp_to_ms("now")
+            >>> timestamp_to_ms("2w-ago") # 2 weeks ago
+            >>> timestamp_to_ms("3d-ahead") # 3 days ahead from now
     """
     if isinstance(timestamp, numbers.Number):  # float, int, int64 etc
         ms = int(timestamp)  # type: ignore[arg-type]
     elif isinstance(timestamp, str):
-        ms = int(round(time.time() * 1000)) - time_ago_to_ms(timestamp)
+        ms = round(time.time() * 1000) - time_shift_to_ms(timestamp)
     elif isinstance(timestamp, datetime):
         ms = datetime_to_ms(timestamp)
     else:
@@ -739,4 +759,29 @@ def to_pandas_freq(granularity: str, start: datetime) -> str:
     return f"{multiplier}{unit}"
 
 
+def timed_cache(ttl: int = 5) -> Callable[[Callable[_P, _T]], Callable[_P, _T]]:
+    """
+    A thread-safe timed cache decorator for a function (that ignores arguments), accepting a custom
+    time-to-live (ttl) for the cached value (seconds).
+    """
+
+    def decorator(func: Callable[_P, _T]) -> Callable[_P, _T]:
+        lock = threading.Lock()
+        value: _T = None  # type: ignore [assignment]
+        start_time = 0.0
+
+        @wraps(func)
+        def wrapper(*a: _P.args, **kw: _P.kwargs) -> _T:
+            nonlocal value, start_time
+            with lock:
+                if (current_time := time.time()) - start_time < ttl:
+                    return value
+                value, start_time = func(*a, **kw), current_time
+                return value
+
+        return wrapper
+
+    return decorator
+
+
 __all__ = ["ZoneInfo", "ZoneInfoNotFoundError"]  # Fix: Module does not explicitly export attribute "ZoneInfo
